@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: SQLColAttributes.c,v 1.14 2008/09/29 14:02:43 lurcher Exp $
+ * $Id: SQLColAttributes.c,v 1.15 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLColAttributes.c,v $
+ * Revision 1.15  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.14  2008/09/29 14:02:43  lurcher
  * Fix missing dlfcn group option
  *
@@ -164,9 +167,10 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLColAttributes.c,v $ $Revision: 1.14 $";
+static char const rcsid[]= "$RCSfile: SQLColAttributes.c,v $ $Revision: 1.15 $";
 
 SQLINTEGER  map_ca_odbc2_to_3( SQLINTEGER field_identifier )
 {
@@ -257,13 +261,13 @@ SQLRETURN SQLColAttributes( SQLHSTMT statement_handle,
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tColumn Number = %d\
-            \n\t\t\tField Identifier = %s\
-            \n\t\t\tCharacter Attr = %p\
-            \n\t\t\tBuffer Length = %d\
-            \n\t\t\tString Length = %p\
-            \n\t\t\tNumeric Attribute = %p",
+\n\t\t\tStatement = %p\
+\n\t\t\tColumn Number = %d\
+\n\t\t\tField Identifier = %s\
+\n\t\t\tCharacter Attr = %p\
+\n\t\t\tBuffer Length = %d\
+\n\t\t\tString Length = %p\
+\n\t\t\tNumeric Attribute = %p",
                 statement,
                 column_number,
                 __col_attr_as_string( s1, field_identifier ),
