@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: SQLColumnPrivilegesW.c,v 1.8 2008/08/29 08:01:38 lurcher Exp $
+ * $Id: SQLColumnPrivilegesW.c,v 1.9 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLColumnPrivilegesW.c,v $
+ * Revision 1.9  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.8  2008/08/29 08:01:38  lurcher
  * Alter the way W functions are passed to the driver
  *
@@ -79,6 +82,7 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
 static char const rcsid[]= "$RCSfile: SQLColumnPrivilegesW.c,v $";
@@ -153,11 +157,11 @@ SQLRETURN SQLColumnPrivilegesW(
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tCatalog Name = %s\
-            \n\t\t\tSchema Name = %s\
-            \n\t\t\tTable Name = %s\
-            \n\t\t\tColumn Name = %s", 
+\n\t\t\tStatement = %p\
+\n\t\t\tCatalog Name = %s\
+\n\t\t\tSchema Name = %s\
+\n\t\t\tTable Name = %s\
+\n\t\t\tColumn Name = %s", 
                 statement,
                 __wstring_with_length( s1, catalog_name, name_length1 ), 
                 __wstring_with_length( s2, schema_name, name_length2 ), 
@@ -200,7 +204,7 @@ SQLRETURN SQLColumnPrivilegesW(
             statement -> state == STATE_S6 ||
             statement -> state == STATE_S7 )
 #else
-    if ( statement -> state == STATE_S6 ||
+    if (( statement -> state == STATE_S6 && statement -> eod == 0 ) ||
             statement -> state == STATE_S7 )
 #endif
     {
@@ -252,6 +256,21 @@ SQLRETURN SQLColumnPrivilegesW(
         }
     }
 
+    if ( table_name == NULL ) 
+    {
+        dm_log_write( __FILE__, 
+                __LINE__, 
+                LOG_INFO, 
+                LOG_INFO, 
+                "Error: HY009" );
+
+        __post_internal_error( &statement -> error,
+                ERROR_HY009, NULL,
+                statement -> connection -> environment -> requested_version );
+
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
+    }
+
     /*
      * TO_DO Check the SQL_ATTR_METADATA_ID settings
      */
