@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: SQLColumns.c,v 1.7 2008/08/29 08:01:38 lurcher Exp $
+ * $Id: SQLColumns.c,v 1.8 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLColumns.c,v $
+ * Revision 1.8  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.7  2008/08/29 08:01:38  lurcher
  * Alter the way W functions are passed to the driver
  *
@@ -138,9 +141,10 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLColumns.c,v $ $Revision: 1.7 $";
+static char const rcsid[]= "$RCSfile: SQLColumns.c,v $ $Revision: 1.8 $";
 
 SQLRETURN SQLColumnsA( SQLHSTMT statement_handle,
            SQLCHAR *catalog_name,
@@ -196,11 +200,11 @@ SQLRETURN SQLColumns( SQLHSTMT statement_handle,
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tCatalog Name = %s\
-            \n\t\t\tSchema Name = %s\
-            \n\t\t\tTable Name = %s\
-            \n\t\t\tColumn Name = %s",
+\n\t\t\tStatement = %p\
+\n\t\t\tCatalog Name = %s\
+\n\t\t\tSchema Name = %s\
+\n\t\t\tTable Name = %s\
+\n\t\t\tColumn Name = %s",
                 statement,
                 __string_with_length( s1, catalog_name, name_length1 ),
                 __string_with_length( s2, schema_name, name_length2 ),
@@ -237,7 +241,7 @@ SQLRETURN SQLColumns( SQLHSTMT statement_handle,
             statement -> state == STATE_S6 ||
             statement -> state == STATE_S7 )
 #else
-    if ( statement -> state == STATE_S6 ||
+    if (( statement -> state == STATE_S6 && statement -> eod == 0 ) ||
             statement -> state == STATE_S7 )
 #endif
     {
@@ -374,7 +378,7 @@ SQLRETURN SQLColumns( SQLHSTMT statement_handle,
 
         if ( ret == SQL_SUCCESS_WITH_INFO )
         {
-            function_return_ex( SQL_HANDLE_STMT, statement, ret, TRUE );
+            function_return_ex( IGNORE_THREAD, statement, ret, TRUE );
         }
         
         SQLNUMRESULTCOLS( statement -> connection,
