@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,15 @@
  *
  **********************************************************************
  *
- * $Id: SQLDrivers.c,v 1.11 2008/09/29 14:02:45 lurcher Exp $
+ * $Id: SQLDrivers.c,v 1.13 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLDrivers.c,v $
+ * Revision 1.13  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
+ * Revision 1.12  2009/02/17 09:47:44  lurcher
+ * Clear up a number of bugs
+ *
  * Revision 1.11  2008/09/29 14:02:45  lurcher
  * Fix missing dlfcn group option
  *
@@ -161,9 +167,10 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLDrivers.c,v $ $Revision: 1.11 $";
+static char const rcsid[]= "$RCSfile: SQLDrivers.c,v $ $Revision: 1.13 $";
 
 #define BUFFERSIZE  1024
 
@@ -219,8 +226,8 @@ SQLRETURN SQLDrivers(
     if ( log_info.log_flag )
     {
         sprintf( environment -> msg, "\n\t\tEntry:\
-            \n\t\t\tEnvironment = %p\
-            \n\t\t\tDirection = %d",
+\n\t\t\tEnvironment = %p\
+\n\t\t\tDirection = %d",
                 environment,
                 (int)fdirection );
 
@@ -233,6 +240,25 @@ SQLRETURN SQLDrivers(
 
     thread_protect( SQL_HANDLE_ENV, environment );
 
+    /*
+     * check that a version has been requested
+     */
+
+    if ( environment -> requested_version == 0 )
+    {
+        dm_log_write( __FILE__, 
+                __LINE__, 
+                LOG_INFO, 
+                LOG_INFO, 
+                "Error: HY010" );
+
+        __post_internal_error( &environment -> error,
+                ERROR_HY010, NULL,
+                SQL_OV_ODBC3 );
+
+        return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
+    }
+
     if ( cb_driver_desc_max < 0 )
     {
         dm_log_write( __FILE__, 
@@ -248,10 +274,6 @@ SQLRETURN SQLDrivers(
         return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
     }
 
-    /*
-     * the DataManager fails if this is in
-     *
-     *
     if ( cb_drvr_attr_max < 0
             || cb_drvr_attr_max == 1 )
     {
@@ -267,26 +289,6 @@ SQLRETURN SQLDrivers(
 
         return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
     }
-     */
-
-    /*
-     * check that a version has been requested
-     */
-
-    if ( environment -> requested_version == 0 )
-    {
-        dm_log_write( __FILE__, 
-                __LINE__, 
-                LOG_INFO, 
-                LOG_INFO, 
-                "Error: HY090" );
-
-        __post_internal_error( &environment -> error,
-                ERROR_HY010, NULL,
-                environment -> requested_version );
-
-        return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
-    }
 
     if ( fdirection != SQL_FETCH_FIRST &&
             fdirection != SQL_FETCH_NEXT )
@@ -358,14 +360,13 @@ try_again:
         }
         else
         {
-            ret = SQL_SUCCESS_WITH_INFO;
+            ret = SQL_SUCCESS;
         }
 
 		if ( sz_driver_attributes ||
                 pcb_drvr_attr )
 		{
             HINI hIni;
-            int string_length = 0;
             char szPropertyName[INI_MAX_PROPERTY_NAME+1];
             char szValue[INI_MAX_PROPERTY_NAME+1];
             char szIniName[ INI_MAX_OBJECT_NAME + 1 ];
@@ -388,9 +389,6 @@ try_again:
                     INI_SUCCESS )
 #endif
             {
-                char pRetBuffer[ 256 ];
-                int nRetBuffer;
-
                 iniObjectSeek( hIni, (char *)object );
                 iniPropertyFirst( hIni );
                 while ( iniPropertyEOL( hIni ) != TRUE )
