@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: SQLForeignKeys.c,v 1.6 2004/01/12 09:54:39 lurcher Exp $
+ * $Id: SQLForeignKeys.c,v 1.7 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLForeignKeys.c,v $
+ * Revision 1.7  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.6  2004/01/12 09:54:39  lurcher
  *
  * Fix problem where STATE_S5 stops metadata calls
@@ -129,9 +132,10 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLForeignKeys.c,v $ $Revision: 1.6 $";
+static char const rcsid[]= "$RCSfile: SQLForeignKeys.c,v $ $Revision: 1.7 $";
 
 SQLRETURN SQLForeignKeysA(
     SQLHSTMT           statement_handle,
@@ -203,13 +207,13 @@ SQLRETURN SQLForeignKeys(
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tPK Catalog Name = %s\
-            \n\t\t\tPK Schema Name = %s\
-            \n\t\t\tPK Table Name = %s\
-            \n\t\t\tFK Catalog Name = %s\
-            \n\t\t\tFK Schema Name = %s\
-            \n\t\t\tFK Table Name = %s",
+\n\t\t\tStatement = %p\
+\n\t\t\tPK Catalog Name = %s\
+\n\t\t\tPK Schema Name = %s\
+\n\t\t\tPK Table Name = %s\
+\n\t\t\tFK Catalog Name = %s\
+\n\t\t\tFK Schema Name = %s\
+\n\t\t\tFK Table Name = %s",
                 statement,
                 __string_with_length( s1, szpk_catalog_name, cbpk_catalog_name ), 
                 __string_with_length( s2, szpk_schema_name, cbpk_schema_name ), 
@@ -250,7 +254,7 @@ SQLRETURN SQLForeignKeys(
             statement -> state == STATE_S6 ||
             statement -> state == STATE_S7 )
 #else
-    if ( statement -> state == STATE_S6 ||
+    if (( statement -> state == STATE_S6 && statement -> eod == 0 ) ||
             statement -> state == STATE_S7 )
 #endif
     {
@@ -407,7 +411,7 @@ SQLRETURN SQLForeignKeys(
 
         if ( ret == SQL_SUCCESS_WITH_INFO )
         {
-            function_return_ex( SQL_HANDLE_STMT, statement, ret, TRUE );
+            function_return_ex( IGNORE_THREAD, statement, ret, TRUE );
         }
 
         SQLNUMRESULTCOLS( statement -> connection,
