@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,15 @@
  *
  **********************************************************************
  *
- * $Id: SQLGetStmtAttrW.c,v 1.5 2008/08/29 08:01:39 lurcher Exp $
+ * $Id: SQLGetStmtAttrW.c,v 1.7 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLGetStmtAttrW.c,v $
+ * Revision 1.7  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
+ * Revision 1.6  2009/02/04 09:30:02  lurcher
+ * Fix some SQLINTEGER/SQLLEN conflicts
+ *
  * Revision 1.5  2008/08/29 08:01:39  lurcher
  * Alter the way W functions are passed to the driver
  *
@@ -66,6 +72,7 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
 static char const rcsid[]= "$RCSfile: SQLGetStmtAttrW.c,v $";
@@ -131,11 +138,11 @@ SQLRETURN SQLGetStmtAttrW( SQLHSTMT statement_handle,
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tAttribute = %s\
-            \n\t\t\tValue = %p\
-            \n\t\t\tBuffer Length = %d\
-            \n\t\t\tStrLen = %p",
+\n\t\t\tStatement = %p\
+\n\t\t\tAttribute = %s\
+\n\t\t\tValue = %p\
+\n\t\t\tBuffer Length = %d\
+\n\t\t\tStrLen = %p",
                 statement,
                 __stmt_attr_as_string( s1, attribute ),
                 value, 
@@ -277,7 +284,7 @@ SQLRETURN SQLGetStmtAttrW( SQLHSTMT statement_handle,
             CHECK_SQLEXTENDEDFETCH( statement -> connection ))
     {
         if ( value )
-            memcpy( value, &statement -> fetch_bm_ptr, sizeof( SQLINTEGER * ));
+            memcpy( value, &statement -> fetch_bm_ptr, sizeof( SQLLEN * ));
 
         ret =  SQL_SUCCESS;
     }
@@ -286,7 +293,7 @@ SQLRETURN SQLGetStmtAttrW( SQLHSTMT statement_handle,
             CHECK_SQLEXTENDEDFETCH( statement -> connection ))
     {
         if ( value )
-            memcpy( value, &statement -> row_st_arr, sizeof( SQLINTEGER * ));
+            memcpy( value, &statement -> row_st_arr, sizeof( SQLLEN * ));
 
         ret = SQL_SUCCESS;
     }
@@ -295,7 +302,7 @@ SQLRETURN SQLGetStmtAttrW( SQLHSTMT statement_handle,
             CHECK_SQLEXTENDEDFETCH( statement -> connection ))
     {
         if ( value )
-            memcpy( value, &statement -> row_ct_ptr, sizeof( SQLUINTEGER * ));
+            memcpy( value, &statement -> row_ct_ptr, sizeof( SQLULEN * ));
 
         ret = SQL_SUCCESS;
     }
