@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: SQLNumParams.c,v 1.3 2003/10/30 18:20:46 lurcher Exp $
+ * $Id: SQLNumParams.c,v 1.4 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: SQLNumParams.c,v $
+ * Revision 1.4  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.3  2003/10/30 18:20:46  lurcher
  *
  * Fix broken thread protection
@@ -98,9 +101,10 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLNumParams.c,v $ $Revision: 1.3 $";
+static char const rcsid[]= "$RCSfile: SQLNumParams.c,v $ $Revision: 1.4 $";
 
 SQLRETURN SQLNumParams(
     SQLHSTMT           statement_handle,
@@ -131,8 +135,8 @@ SQLRETURN SQLNumParams(
     if ( log_info.log_flag )
     {
         sprintf( statement -> msg, "\n\t\tEntry:\
-            \n\t\t\tStatement = %p\
-            \n\t\t\tParam Count = %p",
+\n\t\t\tStatement = %p\
+\n\t\t\tParam Count = %p",
                 statement,
                 pcpar );
 
@@ -216,7 +220,7 @@ SQLRETURN SQLNumParams(
     {
         sprintf( statement -> msg, 
                 "\n\t\tExit:[%s]\
-                \n\t\t\tCount = %s",
+\n\t\t\tCount = %s",
                     __get_return_status( ret, s2 ),
                     __sptr_as_string( s1, pcpar ));
 
