@@ -4,7 +4,7 @@
  * (pharvey@codebydesign.com).
  *
  * Modified and extended by Nick Gorham
- * (nick@easysoft.com).
+ * (nick@lurcher.org).
  *
  * Any bugs or problems should be considered the fault of Nick and not
  * Peter.
@@ -27,9 +27,12 @@
  *
  **********************************************************************
  *
- * $Id: __connection.c,v 1.5 2008/09/29 14:02:45 lurcher Exp $
+ * $Id: __connection.c,v 1.6 2009/02/18 17:59:08 lurcher Exp $
  *
  * $Log: __connection.c,v $
+ * Revision 1.6  2009/02/18 17:59:08  lurcher
+ * Shift to using config.h, the compile lines were making it hard to spot warnings
+ *
  * Revision 1.5  2008/09/29 14:02:45  lurcher
  * Fix missing dlfcn group option
  *
@@ -92,6 +95,7 @@
  *
  **********************************************************************/
 
+#include <config.h>
 #include "drivermanager.h"
 
 /*
@@ -100,7 +104,7 @@
  * variable
  */
 
-static char const rcsid[]= "$RCSfile: __connection.c,v $ $Revision: 1.5 $";
+static char const rcsid[]= "$RCSfile: __connection.c,v $ $Revision: 1.6 $";
 
 /*
  * search for the library (.so) that the DSN points to
