@@ -7,14 +7,17 @@
 #ifndef __SQL_H
 #define __SQL_H
 
+
 /****************************
  * default to 3.51 declare something else before here and you get a whole new ball of wax
  ***************************/
 #ifndef ODBCVER
-#define ODBCVER 0x0351
+#define ODBCVER 0x0380
 #endif
 
+#ifndef __SQLTYPES_H
 #include "sqltypes.h"
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -270,6 +273,7 @@ extern "C" {
 #define SQL_NULL_HSTMT      0
 #if (ODBCVER >= 0x0300)
 #define SQL_NULL_HDESC      0
+#define SQL_NULL_DESC       0
 #endif
 
 /* null handle used in place of parent handle when allocating HENV */
@@ -387,6 +391,10 @@ extern "C" {
 #define SQL_API_SQLTABLES              54
 #define SQL_API_SQLTRANSACT            23
 
+#if (ODBCVER >= 0x0380)
+#define SQL_API_SQLCANCELHANDLE      1022
+#endif
+
 /* Information requested by SQLGetInfo() */
 #if (ODBCVER >= 0x0300)
 #define SQL_MAX_DRIVER_CONNECTIONS           0
@@ -562,254 +570,264 @@ extern "C" {
 #define SQL_NC_HIGH                         0
 #define SQL_NC_LOW                          1
 
-SQLRETURN   SQLAllocConnect(SQLHENV EnvironmentHandle,
-           SQLHDBC *ConnectionHandle);
+    SQLRETURN  SQL_API SQLAllocConnect(SQLHENV EnvironmentHandle,
+                                       SQLHDBC *ConnectionHandle);
 
-SQLRETURN   SQLAllocEnv(SQLHENV *EnvironmentHandle);
+    SQLRETURN  SQL_API SQLAllocEnv(SQLHENV *EnvironmentHandle);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLAllocHandle(SQLSMALLINT HandleType,
-           SQLHANDLE InputHandle, SQLHANDLE *OutputHandle);
+    SQLRETURN  SQL_API SQLAllocHandle(SQLSMALLINT HandleType,
+                                      SQLHANDLE InputHandle, SQLHANDLE *OutputHandle);
 #endif
 
-SQLRETURN   SQLAllocStmt(SQLHDBC ConnectionHandle,
-           SQLHSTMT *StatementHandle);
+    SQLRETURN  SQL_API SQLAllocStmt(SQLHDBC ConnectionHandle,
+                                    SQLHSTMT *StatementHandle);
 
-SQLRETURN   SQLBindCol(SQLHSTMT StatementHandle,
-		   SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
-		   SQLPOINTER TargetValue, SQLLEN BufferLength,
-	   	   SQLLEN *StrLen_or_Ind);
+    SQLRETURN  SQL_API SQLBindCol(SQLHSTMT StatementHandle,
+                                  SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
+                                  SQLPOINTER TargetValue, SQLLEN BufferLength,
+                                  SQLLEN *StrLen_or_Ind);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLBindParam(SQLHSTMT StatementHandle,
-           SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
-           SQLSMALLINT ParameterType, SQLULEN LengthPrecision,
-           SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue,
-           SQLLEN *StrLen_or_Ind);
+    SQLRETURN  SQL_API SQLBindParam(SQLHSTMT StatementHandle,
+                                    SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
+                                    SQLSMALLINT ParameterType, SQLULEN LengthPrecision,
+                                    SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue,
+                                    SQLLEN *StrLen_or_Ind);
 #endif
 
-SQLRETURN   SQLCancel(SQLHSTMT StatementHandle);
+    SQLRETURN  SQL_API SQLCancel(SQLHSTMT StatementHandle);
+
+#if (ODBCVER >= 0x0380)
+SQLRETURN  SQL_API SQLCancelHandle(SQLSMALLINT HandleType, SQLHANDLE InputHandle);
+#endif 
+
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLCloseCursor(SQLHSTMT StatementHandle);
+    SQLRETURN  SQL_API SQLCloseCursor(SQLHSTMT StatementHandle);
 
-SQLRETURN   SQLColAttribute (SQLHSTMT StatementHandle,
-           SQLUSMALLINT ColumnNumber, SQLUSMALLINT FieldIdentifier,
-           SQLPOINTER CharacterAttribute, SQLSMALLINT BufferLength,
-           SQLSMALLINT *StringLength, SQLPOINTER NumericAttribute);
+    SQLRETURN  SQL_API SQLColAttribute(SQLHSTMT StatementHandle,
+                                        SQLUSMALLINT ColumnNumber, SQLUSMALLINT FieldIdentifier,
+                                        SQLPOINTER CharacterAttribute, SQLSMALLINT BufferLength,
+                                        SQLSMALLINT *StringLength, SQLLEN *NumericAttribute );
+
+										/* spec says (SQLPOINTER) not (SQLEN*) - PAH */
+										/* Ms now say SQLLEN* 
+                                           http://msdn.microsoft.com/library/en-us/odbc/htm/dasdkodbcoverview_64bit.asp - NG */
+										
 #endif
 
 
-SQLRETURN   SQLColumns(SQLHSTMT StatementHandle,
-           SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
-           SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
-           SQLCHAR *TableName, SQLSMALLINT NameLength3,
-           SQLCHAR *ColumnName, SQLSMALLINT NameLength4);
+    SQLRETURN  SQL_API SQLColumns(SQLHSTMT StatementHandle,
+                                  SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
+                                  SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
+                                  SQLCHAR *TableName, SQLSMALLINT NameLength3,
+                                  SQLCHAR *ColumnName, SQLSMALLINT NameLength4);
 
 
-SQLRETURN   SQLConnect(SQLHDBC ConnectionHandle,
-           SQLCHAR *ServerName, SQLSMALLINT NameLength1,
-           SQLCHAR *UserName, SQLSMALLINT NameLength2,
-           SQLCHAR *Authentication, SQLSMALLINT NameLength3);
+    SQLRETURN  SQL_API SQLConnect(SQLHDBC ConnectionHandle,
+                                  SQLCHAR *ServerName, SQLSMALLINT NameLength1,
+                                  SQLCHAR *UserName, SQLSMALLINT NameLength2,
+                                  SQLCHAR *Authentication, SQLSMALLINT NameLength3);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLCopyDesc(SQLHDESC SourceDescHandle,
-           SQLHDESC TargetDescHandle);
+    SQLRETURN  SQL_API SQLCopyDesc(SQLHDESC SourceDescHandle,
+                                   SQLHDESC TargetDescHandle);
 #endif
 
-SQLRETURN   SQLDataSources(SQLHENV EnvironmentHandle,
-           SQLUSMALLINT Direction, SQLCHAR *ServerName,
-           SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1,
-           SQLCHAR *Description, SQLSMALLINT BufferLength2,
-           SQLSMALLINT *NameLength2);
+    SQLRETURN  SQL_API SQLDataSources(SQLHENV EnvironmentHandle,
+                                      SQLUSMALLINT Direction, SQLCHAR *ServerName,
+                                      SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1,
+                                      SQLCHAR *Description, SQLSMALLINT BufferLength2,
+                                      SQLSMALLINT *NameLength2);
 
-SQLRETURN   SQLDescribeCol(SQLHSTMT StatementHandle,
-           SQLUSMALLINT ColumnNumber, SQLCHAR *ColumnName,
-           SQLSMALLINT BufferLength, SQLSMALLINT *NameLength,
-           SQLSMALLINT *DataType, SQLULEN *ColumnSize,
-           SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable);
+    SQLRETURN  SQL_API SQLDescribeCol(SQLHSTMT StatementHandle,
+                                      SQLUSMALLINT ColumnNumber, SQLCHAR *ColumnName,
+                                      SQLSMALLINT BufferLength, SQLSMALLINT *NameLength,
+                                      SQLSMALLINT *DataType, SQLULEN *ColumnSize,
+                                      SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable);
 
-SQLRETURN   SQLDisconnect(SQLHDBC ConnectionHandle);
+    SQLRETURN  SQL_API SQLDisconnect(SQLHDBC ConnectionHandle);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLEndTran(SQLSMALLINT HandleType, SQLHANDLE Handle,
-           SQLSMALLINT CompletionType);
+    SQLRETURN  SQL_API SQLEndTran(SQLSMALLINT HandleType, SQLHANDLE Handle,
+                                  SQLSMALLINT CompletionType);
 #endif
 
-SQLRETURN   SQLError(SQLHENV EnvironmentHandle,
-           SQLHDBC ConnectionHandle, SQLHSTMT StatementHandle,
-           SQLCHAR *Sqlstate, SQLINTEGER *NativeError,
-           SQLCHAR *MessageText, SQLSMALLINT BufferLength,
-           SQLSMALLINT *TextLength);
+    SQLRETURN  SQL_API SQLError(SQLHENV EnvironmentHandle,
+                                SQLHDBC ConnectionHandle, SQLHSTMT StatementHandle,
+                                SQLCHAR *Sqlstate, SQLINTEGER *NativeError,
+                                SQLCHAR *MessageText, SQLSMALLINT BufferLength,
+                                SQLSMALLINT *TextLength);
 
-SQLRETURN   SQLExecDirect(SQLHSTMT StatementHandle,
-           SQLCHAR *StatementText, SQLINTEGER TextLength);
+    SQLRETURN  SQL_API SQLExecDirect(SQLHSTMT StatementHandle,
+                                     SQLCHAR *StatementText, SQLINTEGER TextLength);
 
-SQLRETURN   SQLExecute(SQLHSTMT StatementHandle);
+    SQLRETURN  SQL_API SQLExecute(SQLHSTMT StatementHandle);
 
-SQLRETURN   SQLFetch(SQLHSTMT StatementHandle);
+    SQLRETURN  SQL_API SQLFetch(SQLHSTMT StatementHandle);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLFetchScroll(SQLHSTMT StatementHandle,
-           SQLSMALLINT FetchOrientation, SQLROWOFFSET FetchOffset);
+    SQLRETURN  SQL_API SQLFetchScroll(SQLHSTMT StatementHandle,
+                                      SQLSMALLINT FetchOrientation, SQLLEN FetchOffset);
 #endif
 
-SQLRETURN   SQLFreeConnect(SQLHDBC ConnectionHandle);
+    SQLRETURN  SQL_API SQLFreeConnect(SQLHDBC ConnectionHandle);
 
-SQLRETURN   SQLFreeEnv(SQLHENV EnvironmentHandle);
+    SQLRETURN  SQL_API SQLFreeEnv(SQLHENV EnvironmentHandle);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLFreeHandle(SQLSMALLINT HandleType, SQLHANDLE Handle);
+    SQLRETURN  SQL_API SQLFreeHandle(SQLSMALLINT HandleType, SQLHANDLE Handle);
 #endif
 
-SQLRETURN   SQLFreeStmt(SQLHSTMT StatementHandle,
-           SQLUSMALLINT Option);
+    SQLRETURN  SQL_API SQLFreeStmt(SQLHSTMT StatementHandle,
+                                   SQLUSMALLINT Option);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLGetConnectAttr(SQLHDBC ConnectionHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER BufferLength, SQLINTEGER *StringLength);
+    SQLRETURN  SQL_API SQLGetConnectAttr(SQLHDBC ConnectionHandle,
+                                         SQLINTEGER Attribute, SQLPOINTER Value,
+                                         SQLINTEGER BufferLength, SQLINTEGER *StringLength);
 #endif
 
-SQLRETURN   SQLGetConnectOption(SQLHDBC ConnectionHandle,
-           SQLUSMALLINT Option, SQLPOINTER Value);
+    SQLRETURN  SQL_API SQLGetConnectOption(SQLHDBC ConnectionHandle,
+                                           SQLUSMALLINT Option, SQLPOINTER Value);
 
-SQLRETURN   SQLGetCursorName(SQLHSTMT StatementHandle,
-           SQLCHAR *CursorName, SQLSMALLINT BufferLength,
-           SQLSMALLINT *NameLength);
+    SQLRETURN  SQL_API SQLGetCursorName(SQLHSTMT StatementHandle,
+                                        SQLCHAR *CursorName, SQLSMALLINT BufferLength,
+                                        SQLSMALLINT *NameLength);
 
-SQLRETURN   SQLGetData(SQLHSTMT StatementHandle,
-           SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
-           SQLPOINTER TargetValue, SQLLEN BufferLength,
-           SQLLEN *StrLen_or_Ind);
+    SQLRETURN  SQL_API SQLGetData(SQLHSTMT StatementHandle,
+                                  SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
+                                  SQLPOINTER TargetValue, SQLLEN BufferLength,
+                                  SQLLEN *StrLen_or_Ind);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLGetDescField(SQLHDESC DescriptorHandle,
-           SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
-           SQLPOINTER Value, SQLINTEGER BufferLength,
-           SQLINTEGER *StringLength);
+    SQLRETURN   SQLGetDescField(SQLHDESC DescriptorHandle,
+                                SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
+                                SQLPOINTER Value, SQLINTEGER BufferLength,
+                                SQLINTEGER *StringLength);
 
-SQLRETURN   SQLGetDescRec(SQLHDESC DescriptorHandle,
-           SQLSMALLINT RecNumber, SQLCHAR *Name,
-           SQLSMALLINT BufferLength, SQLSMALLINT *StringLength,
-           SQLSMALLINT *Type, SQLSMALLINT *SubType,
-           SQLLEN *Length, SQLSMALLINT *Precision,
-           SQLSMALLINT *Scale, SQLSMALLINT *Nullable);
+    SQLRETURN  SQL_API SQLGetDescRec(SQLHDESC DescriptorHandle,
+                                     SQLSMALLINT RecNumber, SQLCHAR *Name,
+                                     SQLSMALLINT BufferLength, SQLSMALLINT *StringLength,
+                                     SQLSMALLINT *Type, SQLSMALLINT *SubType,
+                                     SQLLEN *Length, SQLSMALLINT *Precision,
+                                     SQLSMALLINT *Scale, SQLSMALLINT *Nullable);
 
-SQLRETURN   SQLGetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
-           SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
-           SQLPOINTER DiagInfo, SQLSMALLINT BufferLength,
-           SQLSMALLINT *StringLength);
+    SQLRETURN  SQL_API SQLGetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
+                                       SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
+                                       SQLPOINTER DiagInfo, SQLSMALLINT BufferLength,
+                                       SQLSMALLINT *StringLength);
 
-SQLRETURN   SQLGetDiagRec(SQLSMALLINT HandleType, SQLHANDLE Handle,
-           SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
-           SQLINTEGER *NativeError, SQLCHAR *MessageText,
-           SQLSMALLINT BufferLength, SQLSMALLINT *TextLength);
+    SQLRETURN  SQL_API SQLGetDiagRec(SQLSMALLINT HandleType, SQLHANDLE Handle,
+                                     SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
+                                     SQLINTEGER *NativeError, SQLCHAR *MessageText,
+                                     SQLSMALLINT BufferLength, SQLSMALLINT *TextLength);
 
-SQLRETURN   SQLGetEnvAttr(SQLHENV EnvironmentHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER BufferLength, SQLINTEGER *StringLength);
+    SQLRETURN  SQL_API SQLGetEnvAttr(SQLHENV EnvironmentHandle,
+                                     SQLINTEGER Attribute, SQLPOINTER Value,
+                                     SQLINTEGER BufferLength, SQLINTEGER *StringLength);
 #endif  /* ODBCVER >= 0x0300 */
 
-SQLRETURN   SQLGetFunctions(SQLHDBC ConnectionHandle,
-           SQLUSMALLINT FunctionId, SQLUSMALLINT *Supported);
+    SQLRETURN  SQL_API SQLGetFunctions(SQLHDBC ConnectionHandle,
+                                       SQLUSMALLINT FunctionId, SQLUSMALLINT *Supported);
 
-SQLRETURN   SQLGetInfo(SQLHDBC ConnectionHandle,
-           SQLUSMALLINT InfoType, SQLPOINTER InfoValue,
-           SQLSMALLINT BufferLength, SQLSMALLINT *StringLength);
+    SQLRETURN  SQL_API SQLGetInfo(SQLHDBC ConnectionHandle,
+                                  SQLUSMALLINT InfoType, SQLPOINTER InfoValue,
+                                  SQLSMALLINT BufferLength, SQLSMALLINT *StringLength);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLGetStmtAttr(SQLHSTMT StatementHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER BufferLength, SQLINTEGER *StringLength);
+    SQLRETURN  SQL_API SQLGetStmtAttr(SQLHSTMT StatementHandle,
+                                      SQLINTEGER Attribute, SQLPOINTER Value,
+                                      SQLINTEGER BufferLength, SQLINTEGER *StringLength);
 #endif  /* ODBCVER >= 0x0300 */
 
-SQLRETURN   SQLGetStmtOption(SQLHSTMT StatementHandle,
-           SQLUSMALLINT Option, SQLPOINTER Value);
+    SQLRETURN  SQL_API SQLGetStmtOption(SQLHSTMT StatementHandle,
+                                        SQLUSMALLINT Option, SQLPOINTER Value);
 
-SQLRETURN   SQLGetTypeInfo(SQLHSTMT StatementHandle,
-           SQLSMALLINT DataType);
+    SQLRETURN  SQL_API SQLGetTypeInfo(SQLHSTMT StatementHandle,
+                                      SQLSMALLINT DataType);
 
-SQLRETURN   SQLNumResultCols(SQLHSTMT StatementHandle,
-           SQLSMALLINT *ColumnCount);
+    SQLRETURN  SQL_API SQLNumResultCols(SQLHSTMT StatementHandle,
+                                        SQLSMALLINT *ColumnCount);
 
-SQLRETURN   SQLParamData(SQLHSTMT StatementHandle,
-           SQLPOINTER *Value);
+    SQLRETURN  SQL_API SQLParamData(SQLHSTMT StatementHandle,
+                                    SQLPOINTER *Value);
 
-SQLRETURN   SQLPrepare(SQLHSTMT StatementHandle,
-           SQLCHAR *StatementText, SQLINTEGER TextLength);
+    SQLRETURN  SQL_API SQLPrepare(SQLHSTMT StatementHandle,
+                                  SQLCHAR *StatementText, SQLINTEGER TextLength);
 
-SQLRETURN   SQLPutData(SQLHSTMT StatementHandle,
-           SQLPOINTER Data, SQLLEN StrLen_or_Ind);
+    SQLRETURN  SQL_API SQLPutData(SQLHSTMT StatementHandle,
+                                  SQLPOINTER Data, SQLLEN StrLen_or_Ind);
 
-SQLRETURN   SQLRowCount(SQLHSTMT StatementHandle,
-	   SQLLEN *RowCount);
+    SQLRETURN  SQL_API SQLRowCount(SQLHSTMT StatementHandle,
+                                   SQLLEN *RowCount);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLSetConnectAttr(SQLHDBC ConnectionHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER StringLength);
+    SQLRETURN  SQL_API SQLSetConnectAttr(SQLHDBC ConnectionHandle,
+                                         SQLINTEGER Attribute, SQLPOINTER Value,
+                                         SQLINTEGER StringLength);
 #endif /* ODBCVER >= 0x0300 */
 
-SQLRETURN   SQLSetConnectOption(SQLHDBC ConnectionHandle,
-           SQLUSMALLINT Option, SQLULEN Value);
+    SQLRETURN  SQL_API SQLSetConnectOption(SQLHDBC ConnectionHandle,
+                                           SQLUSMALLINT Option, SQLULEN Value);
 
-SQLRETURN   SQLSetCursorName(SQLHSTMT StatementHandle,
-           SQLCHAR *CursorName, SQLSMALLINT NameLength);
+    SQLRETURN  SQL_API SQLSetCursorName(SQLHSTMT StatementHandle,
+                                        SQLCHAR *CursorName, SQLSMALLINT NameLength);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLSetDescField(SQLHDESC DescriptorHandle,
-           SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
-           SQLPOINTER Value, SQLINTEGER BufferLength);
+    SQLRETURN  SQL_API SQLSetDescField(SQLHDESC DescriptorHandle,
+                                       SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
+                                       SQLPOINTER Value, SQLINTEGER BufferLength);
 
-SQLRETURN   SQLSetDescRec(SQLHDESC DescriptorHandle,
-           SQLSMALLINT RecNumber, SQLSMALLINT Type,
-           SQLSMALLINT SubType, SQLLEN Length,
-           SQLSMALLINT Precision, SQLSMALLINT Scale,
-           SQLPOINTER Data, SQLLEN *StringLength,
-           SQLLEN *Indicator);
+    SQLRETURN  SQL_API SQLSetDescRec(SQLHDESC DescriptorHandle,
+                                     SQLSMALLINT RecNumber, SQLSMALLINT Type,
+                                     SQLSMALLINT SubType, SQLLEN Length,
+                                     SQLSMALLINT Precision, SQLSMALLINT Scale,
+                                     SQLPOINTER Data, SQLLEN *StringLength,
+                                     SQLLEN *Indicator);
 
-SQLRETURN   SQLSetEnvAttr(SQLHENV EnvironmentHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER StringLength);
+    SQLRETURN  SQL_API SQLSetEnvAttr(SQLHENV EnvironmentHandle,
+                                     SQLINTEGER Attribute, SQLPOINTER Value,
+                                     SQLINTEGER StringLength);
 #endif /* ODBCVER >= 0x0300 */
 
-SQLRETURN   SQLSetParam(SQLHSTMT StatementHandle,
-           SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
-           SQLSMALLINT ParameterType, SQLULEN LengthPrecision,
-           SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue,
-           SQLLEN *StrLen_or_Ind);
+    SQLRETURN  SQL_API SQLSetParam(SQLHSTMT StatementHandle,
+                                   SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
+                                   SQLSMALLINT ParameterType, SQLULEN LengthPrecision,
+                                   SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue,
+                                   SQLLEN *StrLen_or_Ind);
 
 #if (ODBCVER >= 0x0300)
-SQLRETURN   SQLSetStmtAttr(SQLHSTMT StatementHandle,
-           SQLINTEGER Attribute, SQLPOINTER Value,
-           SQLINTEGER StringLength);
+    SQLRETURN  SQL_API SQLSetStmtAttr(SQLHSTMT StatementHandle,
+                                      SQLINTEGER Attribute, SQLPOINTER Value,
+                                      SQLINTEGER StringLength);
 #endif
 
-SQLRETURN   SQLSetStmtOption(SQLHSTMT StatementHandle,
-           SQLUSMALLINT Option, SQLROWCOUNT Value);
+    SQLRETURN  SQL_API SQLSetStmtOption(SQLHSTMT StatementHandle,
+                                        SQLUSMALLINT Option, SQLULEN Value);
 
-SQLRETURN   SQLSpecialColumns(SQLHSTMT StatementHandle,
-           SQLUSMALLINT IdentifierType, SQLCHAR *CatalogName,
-           SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
-           SQLSMALLINT NameLength2, SQLCHAR *TableName,
-           SQLSMALLINT NameLength3, SQLUSMALLINT Scope,
-           SQLUSMALLINT Nullable);
+    SQLRETURN  SQL_API SQLSpecialColumns(SQLHSTMT StatementHandle,
+                                         SQLUSMALLINT IdentifierType, SQLCHAR *CatalogName,
+                                         SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
+                                         SQLSMALLINT NameLength2, SQLCHAR *TableName,
+                                         SQLSMALLINT NameLength3, SQLUSMALLINT Scope,
+                                         SQLUSMALLINT Nullable);
 
-SQLRETURN   SQLStatistics(SQLHSTMT StatementHandle,
-           SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
-           SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
-           SQLCHAR *TableName, SQLSMALLINT NameLength3,
-           SQLUSMALLINT Unique, SQLUSMALLINT Reserved);
+    SQLRETURN  SQL_API SQLStatistics(SQLHSTMT StatementHandle,
+                                     SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
+                                     SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
+                                     SQLCHAR *TableName, SQLSMALLINT NameLength3,
+                                     SQLUSMALLINT Unique, SQLUSMALLINT Reserved);
 
-SQLRETURN   SQLTables(SQLHSTMT StatementHandle,
-           SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
-           SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
-           SQLCHAR *TableName, SQLSMALLINT NameLength3,
-           SQLCHAR *TableType, SQLSMALLINT NameLength4);
+    SQLRETURN   SQL_API SQLTables(SQLHSTMT StatementHandle,
+                                  SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
+                                  SQLCHAR *SchemaName, SQLSMALLINT NameLength2,
+                                  SQLCHAR *TableName, SQLSMALLINT NameLength3,
+                                  SQLCHAR *TableType, SQLSMALLINT NameLength4);
 
-SQLRETURN   SQLTransact(SQLHENV EnvironmentHandle,
-           SQLHDBC ConnectionHandle, SQLUSMALLINT CompletionType);
+    SQLRETURN  SQL_API SQLTransact(SQLHENV EnvironmentHandle,
+                                   SQLHDBC ConnectionHandle, SQLUSMALLINT CompletionType);
 
 #ifdef __cplusplus
 }
